@@ -8,35 +8,35 @@
     Revised BSD License for more details.
     Copyright 2011-2023 Game Maker 2k - https://github.com/GameMaker2k
     Copyright 2011-2023 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski
-    $FileInfo: shortcuts.py - Last Update: 3/9/2023 Ver. 2.7.27 RC 1 - Author: cooldude2k $
+    $FileInfo: shortcuts.py - Last Update: 3/23/2023 Ver. 2.8.4 RC 1 - Author: cooldude2k $
 '''
 
 from __future__ import absolute_import, division, print_function, unicode_literals;
 import upcean.decode.barcode, upcean.support;
 
 ''' // Shortcut Codes by Kazuki Przyborowski '''
-def decode_barcode(bctype,infile,resize=1,barheight=(48, 54),barwidth=1,barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
+def decode_barcode(bctype,infile,resize=1,barheight=(48, 54),barwidth=1,shiftxy=(0, 0),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
  if(bctype not in upcean.support.supported_barcodes("tuple")):
   return False;
  if(hasattr(upcean.decode.barcode, "decode_"+bctype+"_barcode") and callable(getattr(upcean.decode.barcode, "decode_"+bctype+"_barcode"))):
-  return getattr(upcean.decode.barcode, "decode_"+bctype+"_barcode")(infile,resize,barheight,barwidth,barcolor,imageoutlib);
+  return getattr(upcean.decode.barcode, "decode_"+bctype+"_barcode")(infile,resize,barheight,barwidth,shiftxy,barcolor,imageoutlib);
  if(not hasattr(upcean.decode.barcode, "decode_"+bctype+"_barcode") or not callable(getattr(upcean.decode.barcode, "decode_"+bctype+"_barcode"))):
   return False;
  return False;
 
-def validate_decode_barcode(bctype,infile="./barcode.png",resize=1,barheight=(48, 54),barwidth=1,barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
+def validate_decode_barcode(bctype,infile="./barcode.png",resize=1,barheight=(48, 54),barwidth=1,shiftxy=(0, 0),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
  if(bctype not in upcean.support.supported_barcodes("tuple")):
   return False;
  if(bctype=="upca" or bctype=="upce" or bctype=="ean13" or bctype=="ean8" or bctype=="itf" or bctype=="itf6" or bctype=="itf14"):
   if(hasattr(upcean.decode.barcode, "validate_decode_"+bctype+"_barcode") and callable(getattr(upcean.decode.barcode, "validate_decode_"+bctype+"_barcode"))):
-   return getattr(upcean.decode.barcode, "validate_decode_"+bctype+"_barcode")(infile,resize,barheight,barwidth,barcolor,imageoutlib);
+   return getattr(upcean.decode.barcode, "validate_decode_"+bctype+"_barcode")(infile,resize,barheight,barwidth,shiftxy,barcolor,imageoutlib);
   if(not hasattr(upcean.decode.barcode, "validate_decode_"+bctype+"_barcode") or not callable(getattr(upcean.decode.barcode, "validate_decode_"+bctype+"_barcode"))):
    return False;
   return False;
  if(bctype!="upca" and bctype!="upce" and bctype!="ean13" and bctype!="ean8" and bctype!="itf" and bctype!="itf6" and bctype!="itf14"):
-  return decode_barcode(bctype,infile,resize,barheight,barwidth,barcolor,imageoutlib);
+  return decode_barcode(bctype,infile,resize,barheight,barwidth,shiftxy,barcolor,imageoutlib);
 
-def fix_decode_barcode(bctype,infile="./barcode.png",resize=1,barheight=(48, 54),barwidth=1,barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
+def fix_decode_barcode(bctype,infile="./barcode.png",resize=1,barheight=(48, 54),barwidth=1,shiftxy=(0, 0),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
  if(bctype not in upcean.support.supported_barcodes("tuple")):
   return False;
  if(bctype=="upca" or bctype=="upce" or bctype=="ean13" or bctype=="ean8" or bctype=="itf" or bctype=="itf6" or bctype=="itf14"):
@@ -46,4 +46,4 @@ def fix_decode_barcode(bctype,infile="./barcode.png",resize=1,barheight=(48, 54)
    return False;
   return False;
  if(bctype!="upca" and bctype!="upce" and bctype!="ean13" and bctype!="ean8" and bctype!="itf" and bctype!="itf6" and bctype!="itf14"):
-  return decode_barcode(bctype,infile,resize,barheight,barwidth,barcolor,imageoutlib);
+  return decode_barcode(bctype,infile,resize,barheight,barwidth,shiftxy,barcolor,imageoutlib);
