@@ -11,7 +11,7 @@
     Copyright 2011-2023 Game Maker 2k - https://github.com/GameMaker2k
     Copyright 2011-2023 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski
 
-    $FileInfo: getprefix.py - Last Update: 3/9/2023 Ver. 2.7.27 RC 1 - Author: cooldude2k $
+    $FileInfo: getprefix.py - Last Update: 3/23/2023 Ver. 2.8.4 RC 1 - Author: cooldude2k $
 '''
 
 from __future__ import absolute_import, division, print_function, unicode_literals;
@@ -392,6 +392,8 @@ def get_goodwill_upca_barcode_info(upc, infotype=None):
   gw_item_type = "Books";
  elif(re.findall("^(4002000)", upc)):
   gw_item_type = "Mystery Dozen Deal";
+ elif(re.findall("^(4010000)", upc)):
+  gw_item_type = "Bagged Hardlines";
  else:
   gw_item_type = None;
  gw_item_color = None;
