@@ -11,7 +11,7 @@
     Copyright 2011-2023 Game Maker 2k - https://github.com/GameMaker2k
     Copyright 2011-2023 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski
 
-    $FileInfo: oopfuncs.py - Last Update: 3/9/2023 Ver. 2.7.27 RC 1 - Author: cooldude2k $
+    $FileInfo: oopfuncs.py - Last Update: 3/23/2023 Ver. 2.8.4 RC 1 - Author: cooldude2k $
 '''
 
 from __future__ import absolute_import, division, print_function, unicode_literals;
@@ -243,6 +243,7 @@ class decode:
   self.size = 1;
   self.barheight = (48, 54);
   self.barwidth = 1;
+  self.shiftxy = (0, 0);
   self.barcolor = (0, 0, 0);
   self.textcolor = (0, 0, 0);
   self.bgcolor = (255, 255, 255);
@@ -255,16 +256,19 @@ class decode:
     filename = self.filename;
    if(size is None):
     size = self.size;
-   return upcean.decode.decode_barcode(self.type, filename, size, self.barheight, self.barwidth, (self.barcolor, self.textcolor, self.bgcolor), self.imageoutlib);
+   self.code = upcean.decode.decode_barcode(self.type, filename, size, self.barheight, self.barwidth, self.shiftxy, (self.barcolor, self.textcolor, self.bgcolor), self.imageoutlib);
+   return self.code;
   def validate_decode_barcode(self, filename=None, size=None):
    if(filename is None):
     filename = self.filename;
    if(size is None):
     size = self.size;
-   return upcean.decode.validate_decode_barcode(self.type, filename, size, self.barheight, self.barwidth, (self.barcolor, self.textcolor, self.bgcolor), self.imageoutlib);
+   self.code = upcean.decode.decode_barcode(self.type, filename, size, self.barheight, self.barwidth, self.shiftxy, (self.barcolor, self.textcolor, self.bgcolor), self.imageoutlib);
+   return self.code;
   def fix_decode_barcode(self, filename=None, size=None):
    if(filename is None):
     filename = self.filename;
    if(size is None):
     size = self.size;
-   return upcean.decode.fix_decode_barcode(self.type, filename, size, self.barheight, self.barwidth, (self.barcolor, self.textcolor, self.bgcolor), self.imageoutlib);
+   self.code = upcean.decode.fix_decode_barcode(self.type, filename, size, self.barheight, self.barwidth, self.shiftxy, (self.barcolor, self.textcolor, self.bgcolor), self.imageoutlib);
+   return self.code;
